.. _plasmapy-simulation:

**********************************
Simulation (`plasmapy.simulation`)
**********************************

.. py:module:: plasmapy.simulation
.. currentmodule:: plasmapy.simulation

.. toctree::
   :maxdepth: 1
   :caption: Sub-Packages & Modules

   Particle Tracker <particle_tracker/index>
   abstractions
   particle_integrators
   resolution_constraints


.. attention::

   |expect-api-changes|

Introduction
============

The `~plasmapy.simulation` subpackage provides basic, didactic reference
implementations of popular methods of simulating plasmas, and interfaces
to common simulation tools.

API
===

.. automodapi:: plasmapy.simulation
   :heading-chars: ^~
   :noindex:
